#include <iostream>
#include <string>
#include <map> 
#include <math.h>
#include <vector>
#include <algorithm>
#include <cstdio>
#include <set>
#include <queue>
#include <sstream>
#include <deque>
#include <memory.h>
#include <cassert>
#include <ctime>
#include <complex>

using namespace std;

#define ll long long
#pragma comment(linker, "/STACK:64000000")

typedef complex<double> base;
const int MAXN = 1 << 22;
const double PI = acos(-1.0);
int rev[MAXN];
base wlen_pw[MAXN];

void fft (vector<base> & a, bool invert) {
	int n = (int) a.size();
 
	for (int i=1, j=0; i<n; ++i) {
		int bit = n >> 1;
		for (; j>=bit; bit>>=1)
			j -= bit;
		j += bit;
		if (i < j)
			swap (a[i], a[j]);
	}
 
	for (int len=2; len<=n; len<<=1) {
		double ang = 2*PI/len * (invert ? -1 : 1);
		base wlen (cos(ang), sin(ang));
		for (int i=0; i<n; i+=len) {
			base w (1);
			for (int j=0; j<len/2; ++j) {
				base u = a[i+j],  v = a[i+j+len/2] * w;
				a[i+j] = u + v;
				a[i+j+len/2] = u - v;
				w *= wlen;
			}
		}
	}
	if (invert)
		for (int i=0; i<n; ++i)
			a[i] /= n;
}

void multiply (const vector<int> & a, const vector<int> & b, vector<int> & res) {
	vector<base> fa (a.begin(), a.end()),  fb (b.begin(), b.end());
	size_t n = 1;
	while (n < max (a.size(), b.size()))  n <<= 1;
	n <<= 1;
	fa.resize (n),  fb.resize (n);
 
	fft (fa, false),  fft (fb, false);
	for (size_t i=0; i<n; ++i)
		fa[i] *= fb[i];
	fft (fa, true);
 
	res.resize (n);
	for (size_t i=0; i<n; ++i)
		res[i] = int (fa[i].real() + 0.5);
}

int n, m;
string s;
int cc[1 << 19];

bool reading() {
	if (!(cin >> n >> m >> s)) return 0;
    for (int i = 0; i < m; i++) cin >> cc[i];
    return 1;
}

void print(vector<int> a) {
	for (int i = 0; i < a.size(); i++) cout << a[i] << " \n"[i + 1 == a.size()];
}

ll fft_subsolve(char c) {
	vector<int> v1(0, 0), v2(0, 0);

	for (int i = s.length(); i < 2 * s.length(); i++) {
		if (i < s.length()) v1.push_back(0);
		else v1.push_back(s[i % s.length()] == c);
		if (i < s.length()) v2.push_back(0);
		else v2.push_back(s[i % s.length()] == c);
	}


	vector<int> a;
	multiply(v1, v2, a);
	
	ll ans = 0;
	for (int i = 0; i < s.length(); i++) if (s[i] == c) {
		ans += (a[2 * i] - 1) / 2;
	}

	reverse(v2.begin(), v2.end());
	for (int i = 0; i < s.length(); i++) v2.push_back(0);
	reverse(v2.begin(), v2.end());


	multiply(v1, v2, a);
	for (int i = (s.length() + 1) / 2; i < s.length(); i++) if (s[i] == c) {
		ans += (a[2 * i] - (s.length() % 2 == 0 && s[i - s.length() / 2] == c)) / 2;
	}
	for (int i = 0; i < (s.length() + 1) / 2; i++) if (s[i] == c) {
		ans += (a[2 * (i + s.length())] - (s.length() % 2 == 0 && s[(i + s.length()) - s.length() / 2] == c)) / 2;
	}

	int sub = 0;
	if (s.length() % 3 == 0) {
		for (int i = 0; i < s.length(); i++) {
			sub += s[i] == c && s[(i + s.length() / 3) % s.length()] == c && s[(i - s.length() / 3 + s.length()) % s.length()] == c;
		}
		ans -= sub / 3 * 2;
	}

	return ans;
}

ll fft_solve() {
	return fft_subsolve('W') + fft_subsolve('B');
}

int main() {
	freopen("triangles.in", "r", stdin);
	freopen("triangles.out", "w", stdout);

	while (reading()) {
        for (int i = 0; i < m; i++) {
            --cc[i];
            if (s[cc[i]] == 'W') s[cc[i]] = 'B';
            else s[cc[i]] = 'W';
            cout << fft_solve() << endl;
        }   
    }

	return 0;
}